@@ -1,30 +1,28 @@
 ## File Name: gdina_mstep_item_ml.R
-## File Version: 0.877
+## File Version: 0.897
 
-#####################################################
-# GDINA M-step item parameters
+
+#**** GDINA M-step item parameters
 gdina_mstep_item_ml <- function( pjjj, Ilj.ast, Rlj.ast, eps, avoid.zeroprobs,
         Mjjj, invM.list, linkfct, rule, method, iter, delta.new, max.increment, fac.oldxsi,
         jj, delta, rrum.model, delta.fixed, mstep_iter, mstep_conv, devchange,
         regular_type, regular_lam, cd_steps, mono.constr, Aj_mono_constraints_jj, mono_maxiter,
         regular_alpha, regular_tau, regularization_types, prior_intercepts, prior_slopes, use_prior,
-        optimizer="CDM" )
+        regular_weights=NULL, h=1e-4, optimizer="CDM", add_pseudo_count=.005 )
 {
     eps2 <- eps
     delta_jj <- delta[[jj]]
+    if ( ! is.null(regular_weights) ){
+        regular_weights <- regular_weights[[jj]]
+    }
     NP <- length(delta_jj)
     converged <- FALSE
     penalty <- 0
     logprior_value <- 0
     ii <- 0
-    h <- 1E-4   # numerical differentiation parameter
-
     max_increment <- max.increment
-
-    eps_squeeze <- 1E-6
-
-    Rlj.ast <- Rlj.ast + .005
-    Ilj.ast <- Ilj.ast + .05
+    Rlj.ast <- Rlj.ast + add_pseudo_count
+    Ilj.ast <- Ilj.ast + 2*add_pseudo_count
     N <- sum(Ilj.ast)
     diag_only <- FALSE
     regularization <- FALSE
@@ -45,11 +43,17 @@ gdina_mstep_item_ml <- function( pjjj, Ilj.ast, Rlj.ast, eps, avoid.zeroprobs,
     }
     #----
 
-    #------------------ define log-likelihood function
-    ll_FUN <- function(x)
+    #------------------ define log-likelihood function without prior
+    ll_FUN0 <- function(x)
                 {
                     irf1 <- gdina_prob_item_designmatrix( delta_jj=x, Mjjj=Mjjj, linkfct=linkfct, eps_squeeze=eps )
-                    ll <- - sum( Rlj.ast * log(abs(irf1)) + ( Ilj.ast - Rlj.ast ) * log( abs(1 - irf1 ) ) )
+                    ll <- - sum( Rlj.ast * log(abs(irf1)) + ( Ilj.ast - Rlj.ast ) * log( abs(1-irf1 ) ) )
+                    return(ll)
+                }
+    #------------------ define log-likelihood function with prior
+    ll_FUN <- function(x)
+                {
+                    ll <- ll_FUN0(x=x)
                     if (use_prior){
                         ll <- ll - logprior_FUN(x=x, p1=prior_intercepts, p2=prior_slopes)
                     }
@@ -57,20 +61,14 @@ gdina_mstep_item_ml <- function( pjjj, Ilj.ast, Rlj.ast, eps, avoid.zeroprobs,
                 }
     #------------------
 
-    #------------------ define log-likelihood function
-    ll_FUN0 <- function(x)
-                {
-                    irf1 <- gdina_prob_item_designmatrix( delta_jj=x, Mjjj=Mjjj, linkfct=linkfct, eps_squeeze=eps )
-                    ll <- - sum( Rlj.ast * log(abs(irf1)) + ( Ilj.ast - Rlj.ast ) * log( abs(1 - irf1 ) ) )
-                    return(ll)
-                }
     #------------------
     #--- algorithm without monotonicity constraints
     if (optimizer=="CDM"){
         delta_jj <- gdina_mstep_item_ml_algorithm( delta_jj=delta_jj, max_increment=max_increment, regular_lam=regular_lam,
                         regular_type=regular_type, regularization=regularization, ll_FUN=ll_FUN, h=h,
                         mstep_conv=mstep_conv, cd_steps=cd_steps, mstep_iter=mstep_iter,
-                        regular_alpha=regular_alpha, regular_tau=regular_tau, N=N )
+                        regular_alpha=regular_alpha, regular_tau=regular_tau, N=N,
+                        regular_weights=regular_weights)
     }
     if (optimizer=="optim"){
         mod <- stats::optim(par=delta_jj, fn=ll_FUN, method="L-BFGS-B",
@@ -170,8 +168,10 @@ gdina_mstep_item_ml <- function( pjjj, Ilj.ast, Rlj.ast, eps, avoid.zeroprobs,
         x <- delta_jj[-1]
         penalty1 <- cdm_penalty_values( x=x, regular_type=regular_type, regular_lam=regular_lam,
                             regular_alpha=regular_alpha, regular_tau=regular_tau )
+        if ( ! is.null(regular_weights) ){
+            penalty1 <- regular_weights[-1]*penalty1
+        }
         penalty <- N*sum(penalty1)
-        # ll_value <- N*ll_value - penalty
         ll_value <- ll_value - penalty
     }
 
@@ -184,5 +184,5 @@ gdina_mstep_item_ml <- function( pjjj, Ilj.ast, Rlj.ast, eps, avoid.zeroprobs,
                         logprior_value=logprior_value)
     return(res)
 }
-######################################################
+
 
